@@ -124,7 +124,10 @@ class SeasonalityLayer(AutoMLMixIn, metaclass=AutodocABCMeta):
     """
 
     config_class = SeasonalityConfig
-    require_even_sampling = False
+
+    @property
+    def require_even_sampling(self) -> bool:
+        return False
 
     @property
     def require_univariate(self):
@@ -155,7 +158,7 @@ class SeasonalityLayer(AutoMLMixIn, metaclass=AutodocABCMeta):
         model.set_seasonality(theta, train_data.univariates[self.target_name])
 
     def evaluate_theta(
-        self, thetas: Iterator, train_data: TimeSeries, train_config=None
+        self, thetas: Iterator, train_data: TimeSeries, train_config=None, **kwargs
     ) -> Tuple[Any, Optional[ModelBase], Optional[Tuple[TimeSeries, Optional[TimeSeries]]]]:
         # If multiple seasonalities are supported, return a list of all detected seasonalities
         thetas = list(thetas)
